import setuptools

with open("README.rst", "r", encoding="utf-8") as fh:
    long_description = fh.read()

'''install_requires = [
    'arrow==1.2.2',
    'beautifulsoup4==4.11.1',
    'blis==0.7.7',
    'bs4==0.0.1',
    'catalogue==2.0.7',
    'certifi==2022.5.18.1',
    'charset-normalizer==2.0.12',
    'click==8.1.3',
    'colorama==0.4.4',
    'cymem==2.0.6',
    'date-guesser-rc @ git+https://github.com/rncampos/date_guesser@4007399df72fbfba18ab1c9852153cd80eb616e9',
    'ez-setup==0.9',
    'idna==3.3',
    'jellyfish==0.9.0',
    'Jinja2==3.1.2',
    'langcodes==3.3.0',
    'MarkupSafe==2.1.1',
    'murmurhash==1.0.7',
    'networkx==2.8.2',
    'numpy==1.22.4',
    'packaging==21.3',
    'pandas==1.4.2',
    'pathy==0.6.1',
    'pip-reqs==0.10.0',
    'preshed==3.0.6',
    'pt-core-news-lg @ https://github.com/explosion/spacy-models/releases/download/pt_core_news_lg-3.3.0/pt_core_news_lg-3.3.0-py3-none-any.whl',
    'pt-core-news-md @ https://github.com/explosion/spacy-models/releases/download/pt_core_news_md-3.3.0/pt_core_news_md-3.3.0-py3-none-any.whl',
    'pt-core-news-sm @ https://github.com/explosion/spacy-models/releases/download/pt_core_news_sm-3.3.0/pt_core_news_sm-3.3.0-py3-none-any.whl',
    'pydantic==1.8.2',
    'pyparsing==3.0.9',
    'python-dateutil==2.8.2',
    'pytz==2022.1',
    'regex==2022.4.24',
    'requests==2.27.1',
    'segtok==1.5.11',
    'six==1.16.0',
    'smart-open==5.2.1',
    'soupsieve==2.3.2.post1',
    'spacy==3.3.0',
    'spacy-legacy==3.0.9',
    'spacy-loggers==1.0.2',
    'srsly==2.4.3',
    'tabulate==0.8.9',
    'thinc==8.0.16',
    'tqdm==4.64.0',
    'typer==0.4.1',
    'typing_extensions==4.2.0',
    'urllib3==1.26.9',
    'wasabi==0.9.1',
    'yake @ git+https://github.com/LIAAD/yake@4f82feb2dfcf1a313621ecf6e4b2eeda6035d73c'
]'''

setuptools.setup(
    name="ArchiveNews",
    version="0.2",
    author="Diogo Correia",
    author_email="diogofccorreia01@gmail.com",
    description="A module that allows you to get and analyze news in detail",
    long_description=long_description,
    license='MIT',
    long_description_content_type="text/markdown",
    url="https://github.com/diogocorreia01/ArchiveNews.git",
    project_urls={
        "Arquivo Publico": "https://arquivopublico.ipt.pt/",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=setuptools.find_packages(where="requirements.txt"),
    python_requires=">=3.6",
)